﻿using System;
using System.Data.OleDb;
using System.Windows.Forms;

using DevExpress.Data.PivotGrid;
using DevExpress.XtraEditors;
using DevExpress.XtraPivotGrid;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 연결
        /// </summary>
        private OleDbConnection connection;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.connection = new OleDbConnection("Provider=Microsoft.Jet.OLEDB.4.0;Data Source=nwind.mdb");

            this.pivotGridControl.OptionsView.RowTotalsLocation = PivotRowTotalsLocation.Tree;

            this.pivotGridControl.DataSource = Order.GetOrderList(this.connection);

            this.pivotGridControl.RetrieveFields();

            PivotGridField orderIDField     = this.pivotGridControl.Fields["OrderID"    ];
            PivotGridField orderDateField   = this.pivotGridControl.Fields["OrderDate"  ];
            PivotGridField shipCountryField = this.pivotGridControl.Fields["ShipCountry"];
            PivotGridField shipCityField    = this.pivotGridControl.Fields["ShipCity"   ];

            shipCountryField.Area = PivotArea.RowArea;

            shipCityField.Area = PivotArea.RowArea;

            orderDateField.Area          = PivotArea.ColumnArea;
            orderDateField.GroupInterval = PivotGroupInterval.DateMonthYear;

            orderIDField.Area        = PivotArea.DataArea;
            orderIDField.SummaryType = PivotSummaryType.Count;

            Shown += Form_Shown;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 폼 표시후 처리하기 - Form_Shown(sender, e)

        /// <summary>
        /// 폼 표시후 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Form_Shown(object sender, EventArgs e)
        {
            if(!this.pivotGridControl.IsPrintingAvailable)
            {
                XtraMessageBox.Show
                (
                    this,
                    "Missing DevExpress.XtraPrinting library",
                    "INFORMATION",
                    MessageBoxButtons.OK,
                    MessageBoxIcon.Information
                );

                return;
            }

            this.pivotGridControl.ShowRibbonPrintPreview();
        }

        #endregion
    }
}